@@ -286,8 +286,8 @@ def LoadCORVISData(datasourceToLoad = CORVISDatasources.ALL, dataPath='./', forc
 
     if verbose:
       print('Loading CTP data...')
-    ctpMetrics = ['positive', 'negative', 'hospitalizedCumulative', 'inIcuCumulative', 'onVentilatorCumulative', 'recovered']
-    ctpMetricEnums = [CORVISMetrics.CONFIRMED, CORVISMetrics.NEGATIVE, CORVISMetrics.HOSPITALIZED, CORVISMetrics.ICU, CORVISMetrics.VENTILATOR, CORVISMetrics.RECOVERED]
+    ctpMetrics = ['positive', 'negative', 'hospitalizedCumulative', 'inIcuCumulative', 'onVentilatorCumulative', 'recovered', 'death']
+    ctpMetricEnums = [CORVISMetrics.CONFIRMED, CORVISMetrics.NEGATIVE, CORVISMetrics.HOSPITALIZED, CORVISMetrics.ICU, CORVISMetrics.VENTILATOR, CORVISMetrics.RECOVERED, CORVISMetrics.DEATH]
     ctpDataframes = []
 
     proceedWithDownload = False
@@ -699,11 +699,14 @@ def FilterCORVISData(sourceCORVISDataframe, country=None, state=None, county=Non
   # Thus, if our last column in the return set is all zeroes, drop it.
   # repeat this process until all empty columns are gone.
 
-  while (returnDataframe.iloc[:,-1].isna()).all():
-    returnDataframe = returnDataframe.iloc[:, :-1]
+  try:
+    while (returnDataframe.iloc[:,-1].isna()).all():
+      returnDataframe = returnDataframe.iloc[:, :-1]
 
-  while (returnDataframe.iloc[:,-1] == 0).all():
-    returnDataframe = returnDataframe.iloc[:, :-1]
+    while (returnDataframe.iloc[:,-1] == 0).all():
+      returnDataframe = returnDataframe.iloc[:, :-1]
+  except:
+    raise ValueError('Error: the filtered dataset is empty.')
 
   return returnDataframe
   
